use clap::Parser;

// 构建命令行工具的结构体
/// cvrf2cusa 是一个用于将 CVRF（Common Vulnerability Reporting Framework）格式的安全报告转换为
/// CUSA（CULinux Security Advisory）的工具，其输入格式为 Xml ，输出格式则为 Json。
#[derive(Clone, Debug, Parser)]
#[command(author, version, about, long_about = None)]
pub struct Cli {
    /// 输入的文件，应为 cvrf 格式的 xml
    #[arg(short, long)]
    pub input: String,

    /// 可选项，将 cvrf 转换为 cusa 后输出到对应的文件中，格式为 json
    #[arg(short, long)]
    pub output: Option<String>,

    /// 是否在终端打印转换后的 cusa 内容，若不指定输出文件，则输出至终端，
    /// 在指定 output 后同时使用该选项，亦可同时输出至文件和终端
    #[arg(short, long, default_value_t = false)]
    pub print: bool,
}

// 从命令行环境变量读取并转换为 `Cli`
pub fn parse() -> Cli {
    Cli::parse()
}
